@@ -146,6 +146,15 @@ public:
                 m_documents.remove(*it);
                 it = it1.value().erase(it);
                 --m_maxParseJobs; //We have added one when putting the document into m_documents
+                
+                if(!m_documents.isEmpty())
+                {
+                    // Only try creating one parse-job at a time, else we might iterate through thousands of files
+                    // without finding a language-support, and block the UI for a long time.
+                    // If there are more documents to parse, instantly re-try.
+                    QMetaObject::invokeMethod(m_parser, "parseDocuments", Qt::QueuedConnection);
+                    break;
+                }
             }
         }
 
