@@ -69,6 +69,19 @@ DumpChain::~DumpChain( )
 {
 }
 
+class Indent {
+private:
+  int m_level;
+public:
+  Indent(int level): m_level(level) {}
+  friend QDebug operator<<(QDebug debug, const Indent& ind) {
+    for (int i=0; i<ind.m_level; i++) {
+      debug << ' ';
+    }
+    return debug;
+  }
+};
+
 void DumpChain::dump( DUContext * context, int allowedDepth )
 {
   if(!top)
