@@ -59,7 +59,7 @@ void CheckoutDialog::jobFinished(KJob * job)
 
     static QRegExp re_file("^.\\s(.*)");
     bool error = false;
-    QStringList lines = cvsjob->output().split("\n");
+    QStringList lines = cvsjob->output().split('\n');
     foreach(const QString &line, lines) {
         if (line.isEmpty()) {
             // ignore empty lines
@@ -74,10 +74,9 @@ void CheckoutDialog::jobFinished(KJob * job)
         }
     }
 
-
     if (error) {
         KMessageBox::error(this,
-            i18n("Some errors occurred while checking out into") + localWorkingDir->url().path(),
+            i18n("Some errors occurred while checking out into") + localWorkingDir->url().toLocalFile(),
             i18n("Checkout Error"));
     } else {
         KDialog::accept();
